from setuptools import setup
import setuptools

setup(name='Berrys_test_package',
      version='0.1',
      description='lets figure this out',
      author='Berry Adams',
      license='NA',
      packages=setuptools.find_packages(),
      zip_safe=False)